@@ -1,4 +1,4 @@
-"""Exports from bareclient"""
+"""bareclient"""
 
 from .client import HttpClient
 from .session import HttpSession
@@ -12,7 +12,13 @@ from .helpers import (
     post_text,
     post_json
 )
-from .acgi import create_ssl_context_with_cert_chain
+from .constants import DEFAULT_PROTOCOLS, DEFAULT_DECOMPRESSORS
+from .ssl_contexts import (
+    create_ssl_context,
+    create_ssl_context_with_cert_chain,
+    DEFAULT_CIPHERS,
+    DEFAULT_OPTIONS
+)
 
 __all__ = [
     'HttpClient',
@@ -25,5 +31,10 @@ __all__ = [
     'post',
     'post_text',
     'post_json',
-    'create_ssl_context_with_cert_chain'
+    'create_ssl_context',
+    'create_ssl_context_with_cert_chain',
+    'DEFAULT_PROTOCOLS',
+    'DEFAULT_CIPHERS',
+    'DEFAULT_OPTIONS',
+    'DEFAULT_DECOMPRESSORS'
 ]
